Package: evolved
Title: Open Software for Teaching Evolutionary Biology at Multiple
        Scales Through Virtual Inquiries
Version: 1.0.0
Authors@R: 
    c(person("Matheus", "Januario", email="januarioml.eco@gmail.com", role = c("aut", "cph", "cre"),
           comment = c(ORCID = "0000-0002-6480-7095")),
      person("Jennifer", "Auler", email="auler.jennifer@gmail.com", role = c("aut"),
           comment = c(ORCID = "0000-0001-7576-9058")),
      person("Andressa", "Viol", email="aviol@umich.edu", role = c("aut")),
      person("Daniel", "Rabosky", email="drabosky@umich.edu", role = c("aut")))
Description: "Evolutionary Virtual Education" - 'evolved' - provides multiple tools to help educators (especially at the graduate level or in advanced undergraduate level courses) apply inquiry-based learning in general evolution classes. In particular, the tools provided include functions that simulate evolutionary processes (e.g., genetic drift, natural selection within a single locus) or concepts (e.g. Hardy-Weinberg equilibrium, phylogenetic distribution of traits). More than only simulating, the package also provides tools for students to analyze (e.g., measuring, testing, visualizing) datasets with characteristics that are common to many fields related to evolutionary biology. Importantly, the package is heavily oriented towards providing tools for inquiry-based learning - where students follow scientific practices to actively construct knowledge. For additional details, see package's vignettes.
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: ape, diversitree, phytools
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), LSD, paleobioDB,
        BAMMtools, plot3D
Config/testthat/edition: 3
Depends: R (>= 2.10)
LazyData: true
VignetteBuilder: knitr
URL: <https://github.com/Auler-J/evolved>
BugReports: https://github.com/Auler-J/evolved/issues
NeedsCompilation: no
Packaged: 2024-11-26 15:47:16 UTC; matheus
Author: Matheus Januario [aut, cph, cre]
    (<https://orcid.org/0000-0002-6480-7095>),
  Jennifer Auler [aut] (<https://orcid.org/0000-0001-7576-9058>),
  Andressa Viol [aut],
  Daniel Rabosky [aut]
Maintainer: Matheus Januario <januarioml.eco@gmail.com>
Repository: CRAN
Date/Publication: 2024-11-27 12:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 07:19:26 UTC; unix
