## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)
options(rmarkdown.html_vignette.check_title = FALSE)

## -----------------------------------------------------------------------------
library(evolved)

## ---- echo=F, fig.cap="Light and carbonaria morphs of the peppered moth on the same lichenous tree. Image from wikicommons.", out.width=500----
knitr::include_graphics('2_morphs.png')

